==> components-2.0.10.tgz: package/esm/Atoms/Tables/TableCell.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

var selectAlign = function selectAlign(align) {
  switch (align) {
    case 'left':
      return 'flex-start';

    case 'center':
      return 'center';

    case 'right':
      return 'flex-end';
  }
};

var Wrapper =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-16acrto-0"
})(["display:flex;flex-direction:row;justify-content:", ";align-items:center;min-width:0;flex-basis:", ";& > *{display:", ";text-overflow:", ";overflow:", ";white-space:", ";}"], function (props) {
  return selectAlign(props.align);
}, function (props) {
  return props.width;
}, function (props) {
  return props.shrinked ? 'block' : 'initial';
}, function (props) {
  return props.shrinked ? 'ellipsis' : 'initial';
}, function (props) {
  return props.shrinked ? 'hidden' : 'initial';
}, function (props) {
  return props.shrinked ? 'nowrap' : 'initial';
});

var TableCell = function TableCell(_ref) {
  var children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement(Wrapper, rest, children);
};

TableCell.propTypes = process.env.NODE_ENV !== "production" ? {
  align: PropTypes.oneOf(['left', 'center', 'right']),
  children: PropTypes.node,
  shrinked: PropTypes.bool,
  width: PropTypes.string
} : {};
TableCell.defaultProps = {
  align: 'left',
  shrinked: true,
  width: '100%'
};
export default TableCell;

==> components-2.2.0.tgz: package/esm/Atoms/Tables/TableCell.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

var selectAlign = function selectAlign(align) {
  switch (align) {
    case 'left':
      return 'flex-start';

    case 'center':
      return 'center';

    case 'right':
      return 'flex-end';
  }
};

var Wrapper =
/*#__PURE__*/
styled.div.withConfig({
  componentId: "sc-16acrto-0"
})(["\n  display: flex;\n  flex-direction: row;\n  justify-content: ", ";\n  align-items: center;\n  min-width: 0;\n  flex-basis: ", ";\n\n  & > * {\n    display: ", ";\n    text-overflow: ", ";\n    overflow: ", ";\n    white-space: ", ";\n  }\n"], function (props) {
  return selectAlign(props.align);
}, function (props) {
  return props.width;
}, function (props) {
  return props.shrinked ? 'block' : 'initial';
}, function (props) {
  return props.shrinked ? 'ellipsis' : 'initial';
}, function (props) {
  return props.shrinked ? 'hidden' : 'initial';
}, function (props) {
  return props.shrinked ? 'nowrap' : 'initial';
});

var TableCell = function TableCell(_ref) {
  var children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement(Wrapper, rest, children);
};

TableCell.propTypes = process.env.NODE_ENV !== "production" ? {
  align: PropTypes.oneOf(['left', 'center', 'right']),
  children: PropTypes.node,
  shrinked: PropTypes.bool,
  width: PropTypes.string
} : {};
TableCell.defaultProps = {
  align: 'left',
  shrinked: true,
  width: '100%'
};
export default TableCell;
